@@ -25,14 +25,13 @@ def main():
     for tractogram in args.tractograms:
         tractogram_format = nib.streamlines.detect_format(tractogram)
         if tractogram_format is not nib.streamlines.TrkFile:
-            print("Skipping non TRK file: '{}'".format(tractogram))
+            print(f"Skipping non TRK file: '{tractogram}'")
             continue
 
         filename, _ = os.path.splitext(tractogram)
         output_filename = filename + '.tck'
         if os.path.isfile(output_filename) and not args.force:
-            msg = "Skipping existing file: '{}'. Use -f to overwrite."
-            print(msg.format(output_filename))
+            print(f"Skipping existing file: '{output_filename}'. Use -f to overwrite.")
             continue
 
         trk = nib.streamlines.load(tractogram)
