@@ -106,8 +106,7 @@ def assert_default_types(loaded):
             continue
         loadedtype = type(getattr(loaded, attr))
         assert loadedtype == defaulttype, (
-            "Type mismatch for attribute: {} ({!s} != {!s})".format(
-                attr, loadedtype, defaulttype))
+            f"Type mismatch for attribute: {attr} ({loadedtype} != {defaulttype})")
 
 
 def test_default_types():
