@@ -12,21 +12,20 @@
 import os
 import numpy as np
 
-from .filename_parser import splitext_addext
+from .filename_parser import splitext_addext, _stringify_path
 from .openers import ImageOpener
 from .filebasedimages import ImageFileError
 from .imageclasses import all_image_classes
 from .arrayproxy import is_proxy
-from .py3k import FileNotFoundError
 from .deprecated import deprecate_with_version
 
 
 def load(filename, **kwargs):
-    ''' Load file given filename, guessing at file type
+    r""" Load file given filename, guessing at file type
 
     Parameters
     ----------
-    filename : string
+    filename : str or os.PathLike
        specification of file to load
     \*\*kwargs : keyword arguments
         Keyword arguments to format-specific load
@@ -35,13 +34,17 @@ def load(filename, **kwargs):
     -------
     img : ``SpatialImage``
        Image of guessed type
-    '''
+    """
+    filename = _stringify_path(filename)
+
+    # Check file exists and is not empty
     try:
         stat_result = os.stat(filename)
     except OSError:
-        raise FileNotFoundError("No such file or no access: '%s'" % filename)
+        raise FileNotFoundError(f"No such file or no access: '{filename}'")
     if stat_result.st_size <= 0:
-        raise ImageFileError("Empty file: '%s'" % filename)
+        raise ImageFileError(f"Empty file: '{filename}'")
+
     sniff = None
     for image_klass in all_image_classes:
         is_valid, sniff = image_klass.path_maybe_image(filename, sniff)
@@ -49,13 +52,10 @@ def load(filename, **kwargs):
             img = image_klass.from_filename(filename, **kwargs)
             return img
 
-    raise ImageFileError('Cannot work out file type of "%s"' %
-                         filename)
+    raise ImageFileError(f'Cannot work out file type of "{filename}"')
 
 
-@deprecate_with_version('guessed_image_type deprecated.'
-                        '2.1',
-                        '4.0')
+@deprecate_with_version('guessed_image_type deprecated.', '3.2', '5.0')
 def guessed_image_type(filename):
     """ Guess image type from file `filename`
 
@@ -75,24 +75,24 @@ def guessed_image_type(filename):
         if is_valid:
             return image_klass
 
-    raise ImageFileError('Cannot work out file type of "%s"' %
-                         filename)
+    raise ImageFileError(f'Cannot work out file type of "{filename}"')
 
 
 def save(img, filename):
-    ''' Save an image to file adapting format to `filename`
+    """ Save an image to file adapting format to `filename`
 
     Parameters
     ----------
     img : ``SpatialImage``
        image to save
-    filename : str
+    filename : str or os.PathLike
        filename (often implying filenames) to which to save `img`.
 
     Returns
     -------
     None
-    '''
+    """
+    filename = _stringify_path(filename)
 
     # Save the type as expected
     try:
@@ -126,8 +126,7 @@ def save(img, filename):
         valid_klasses = [klass for klass in all_image_classes
                          if ext in klass.valid_exts]
         if not valid_klasses:  # if list is empty
-            raise ImageFileError('Cannot work out file type of "%s"' %
-                                 filename)
+            raise ImageFileError(f'Cannot work out file type of "{filename}"')
 
         # Got a list of valid extensions, but that's no guarantee
         #   the file conversion will work. So, try each image
@@ -148,15 +147,15 @@ def save(img, filename):
     converted.to_filename(filename)
 
 
-@deprecate_with_version('read_img_data deprecated.'
-                        'Please use ``img.dataobj.get_unscaled()`` instead.'
-                        '2.0.1',
-                        '4.0')
+@deprecate_with_version('read_img_data deprecated. '
+                        'Please use ``img.dataobj.get_unscaled()`` instead.',
+                        '3.2',
+                        '5.0')
 def read_img_data(img, prefer='scaled'):
     """ Read data from image associated with files
 
     If you want unscaled data, please use ``img.dataobj.get_unscaled()``
-    instead.  If you want scaled data, use ``img.get_data()`` (which will cache
+    instead.  If you want scaled data, use ``img.get_fdata()`` (which will cache
     the loaded array) or ``np.array(img.dataobj)`` (which won't cache the
     array). If you want to load the data as for a modified header, save the
     image with the modified header, and reload.
@@ -165,7 +164,7 @@ def read_img_data(img, prefer='scaled'):
     ----------
     img : ``SpatialImage``
        Image with valid image file in ``img.file_map``.  Unlike the
-       ``img.get_data()`` method, this function returns the data read
+       ``img.get_fdata()`` method, this function returns the data read
        from the image file, as specified by the *current* image header
        and *current* image files.
     prefer : str, optional
@@ -203,7 +202,7 @@ def read_img_data(img, prefer='scaled'):
     other formats with more complicated scaling - such as MINC.
     """
     if prefer not in ('scaled', 'unscaled'):
-        raise ValueError('Invalid string "%s" for "prefer"' % prefer)
+        raise ValueError(f'Invalid string "{prefer}" for "prefer"')
     hdr = img.header
     if not hasattr(hdr, 'raw_data_from_fileobj'):
         # We can only do scaled
@@ -235,9 +234,7 @@ def read_img_data(img, prefer='scaled'):
         return hdr.raw_data_from_fileobj(fileobj)
 
 
-@deprecate_with_version('which_analyze_type deprecated.'
-                        '2.1',
-                        '4.0')
+@deprecate_with_version('which_analyze_type deprecated.', '3.2', '4.0')
 def which_analyze_type(binaryblock):
     """ Is `binaryblock` from NIfTI1, NIfTI2 or Analyze header?
 
