@@ -1,6 +1,6 @@
-''' CSA header reader from SPM spec
+""" CSA header reader from SPM spec
 
-'''
+"""
 import numpy as np
 
 from .structreader import Unpacker
@@ -30,7 +30,7 @@ class CSAReadError(CSAError):
 
 
 def get_csa_header(dcm_data, csa_type='image'):
-    ''' Get CSA header information from DICOM header
+    """ Get CSA header information from DICOM header
 
     Return None if the header does not contain CSA information of the
     specified `csa_type`
@@ -49,14 +49,14 @@ def get_csa_header(dcm_data, csa_type='image'):
     csa_info : None or dict
        Parsed CSA field of `csa_type` or None, if we cannot find the CSA
        information.
-    '''
+    """
     csa_type = csa_type.lower()
     if csa_type == 'image':
         element_offset = 0x10
     elif csa_type == 'series':
         element_offset = 0x20
     else:
-        raise ValueError('Invalid CSA header type "%s"' % csa_type)
+        raise ValueError(f'Invalid CSA header type "{csa_type}"')
     if not (0x29, 0x10) in dcm_data:  # Cannot be Siemens CSA
         return None
     section_start = find_private_section(dcm_data, 0x29, 'SIEMENS CSA HEADER')
@@ -72,7 +72,7 @@ def get_csa_header(dcm_data, csa_type='image'):
 
 
 def read(csa_str):
-    ''' Read CSA header from string `csa_str`
+    """ Read CSA header from string `csa_str`
 
     Parameters
     ----------
@@ -85,7 +85,7 @@ def read(csa_str):
        header information as dict, where `header` has fields (at least)
        ``type, n_tags, tags``.  ``header['tags']`` is also a dictionary
        with one key, value pair for each tag in the header.
-    '''
+    """
     csa_len = len(csa_str)
     csa_dict = {'tags': {}}
     hdr_id = csa_str[:4]
@@ -123,8 +123,7 @@ def read(csa_str):
         if tag_no == 1:
             tag0_n_items = n_items
         if n_items > MAX_CSA_ITEMS:
-            raise CSAReadError('Expected <= {0} tags, got {1}'.format(
-                MAX_CSA_ITEMS, n_items))
+            raise CSAReadError(f'Expected <= {MAX_CSA_ITEMS} tags, got {n_items}')
         items = []
         for item_no in range(n_items):
             x0, x1, x2, x3 = up_str.unpack('4i')
@@ -185,7 +184,7 @@ def get_vector(csa_dict, tag_name, n):
 
 
 def is_mosaic(csa_dict):
-    ''' Return True if the data is of Mosaic type
+    """ Return True if the data is of Mosaic type
 
     Parameters
     ----------
@@ -197,7 +196,7 @@ def is_mosaic(csa_dict):
     tf : bool
        True if the `dcm_data` appears to be of Siemens mosaic type,
        False otherwise
-    '''
+    """
     if csa_dict is None:
         return False
     if get_acq_mat_txt(csa_dict) is None:
@@ -244,7 +243,7 @@ def get_ice_dims(csa_dict):
 
 
 def nt_str(s):
-    ''' Strip string to first null
+    """ Strip string to first null
 
     Parameters
     ----------
@@ -254,7 +253,7 @@ def nt_str(s):
     -------
     sdash : str
        s stripped to first occurence of null (0)
-    '''
+    """
     zero_pos = s.find(b'\x00')
     if zero_pos == -1:
         return s
