@@ -87,17 +87,20 @@ class TestTRK(unittest.TestCase):
     def test_load_empty_file(self):
         for lazy_load in [False, True]:
             trk = TrkFile.load(DATA['empty_trk_fname'], lazy_load=lazy_load)
-            assert_tractogram_equal(trk.tractogram, DATA['empty_tractogram'])
+            with pytest.warns(Warning if lazy_load else None):
+                assert_tractogram_equal(trk.tractogram, DATA['empty_tractogram'])
 
     def test_load_simple_file(self):
         for lazy_load in [False, True]:
             trk = TrkFile.load(DATA['simple_trk_fname'], lazy_load=lazy_load)
-            assert_tractogram_equal(trk.tractogram, DATA['simple_tractogram'])
+            with pytest.warns(Warning if lazy_load else None):
+                assert_tractogram_equal(trk.tractogram, DATA['simple_tractogram'])
 
     def test_load_complex_file(self):
         for lazy_load in [False, True]:
             trk = TrkFile.load(DATA['complex_trk_fname'], lazy_load=lazy_load)
-            assert_tractogram_equal(trk.tractogram, DATA['complex_tractogram'])
+            with pytest.warns(Warning if lazy_load else None):
+                assert_tractogram_equal(trk.tractogram, DATA['complex_tractogram'])
 
     def trk_with_bytes(self, trk_key='simple_trk_fname', endian='<'):
         """ Return example trk file bytes and struct view onto bytes """
@@ -129,12 +132,9 @@ class TestTRK(unittest.TestCase):
         # Simulate a TRK where `vox_to_ras` is not recorded (i.e. all zeros).
         trk_struct, trk_bytes = self.trk_with_bytes()
         trk_struct[Field.VOXEL_TO_RASMM] = np.zeros((4, 4))
-        with clear_and_catch_warnings(record=True, modules=[trk_module]) as w:
+        with pytest.warns(HeaderWarning, match="identity"):
             trk = TrkFile.load(BytesIO(trk_bytes))
-            assert len(w) == 1
-            assert issubclass(w[0].category, HeaderWarning)
-            assert "identity" in str(w[0].message)
-            assert_array_equal(trk.affine, np.eye(4))
+        assert_array_equal(trk.affine, np.eye(4))
 
         # Simulate a TRK where `vox_to_ras` is invalid.
         trk_struct, trk_bytes = self.trk_with_bytes()
@@ -146,18 +146,14 @@ class TestTRK(unittest.TestCase):
         # Simulate a TRK file where `voxel_order` was not provided.
         trk_struct, trk_bytes = self.trk_with_bytes()
         trk_struct[Field.VOXEL_ORDER] = b''
-        with clear_and_catch_warnings(record=True, modules=[trk_module]) as w:
+        with pytest.warns(HeaderWarning, match="LPS"):
             TrkFile.load(BytesIO(trk_bytes))
-            assert len(w) == 1
-            assert issubclass(w[0].category, HeaderWarning)
-            assert "LPS" in str(w[0].message)
 
         # Simulate a TRK file with an unsupported version.
         trk_struct, trk_bytes = self.trk_with_bytes()
         trk_struct['version'] = 123
         with pytest.raises(HeaderError):
             TrkFile.load(BytesIO(trk_bytes))
-        
 
         # Simulate a TRK file with a wrong hdr_size.
         trk_struct, trk_bytes = self.trk_with_bytes()
@@ -186,13 +182,10 @@ class TestTRK(unittest.TestCase):
         assert_array_equal(trk.affine, np.diag([2, 3, 4, 1]))
         # Next check that affine assumed identity if version 1.
         trk_struct['version'] = 1
-        with clear_and_catch_warnings(record=True, modules=[trk_module]) as w:
+        with pytest.warns(HeaderWarning, match="identity"):
             trk = TrkFile.load(BytesIO(trk_bytes))
-            assert len(w) == 1
-            assert issubclass(w[0].category, HeaderWarning)
-            assert "identity" in str(w[0].message)
-            assert_array_equal(trk.affine, np.eye(4))
-            assert_array_equal(trk.header['version'], 1)
+        assert_array_equal(trk.affine, np.eye(4))
+        assert_array_equal(trk.header['version'], 1)
 
     def test_load_complex_file_in_big_endian(self):
         trk_struct, trk_bytes = self.trk_with_bytes(
@@ -206,7 +199,8 @@ class TestTRK(unittest.TestCase):
         for lazy_load in [False, True]:
             trk = TrkFile.load(DATA['complex_trk_big_endian_fname'],
                                lazy_load=lazy_load)
-            assert_tractogram_equal(trk.tractogram, DATA['complex_tractogram'])
+            with pytest.warns(Warning if lazy_load else None):
+                assert_tractogram_equal(trk.tractogram, DATA['complex_tractogram'])
 
     def test_tractogram_file_properties(self):
         trk = TrkFile.load(DATA['simple_trk_fname'])
@@ -373,7 +367,7 @@ class TestTRK(unittest.TestCase):
         # TRK supports up to 10 data_per_point.
         data_per_point = {}
         for i in range(10):
-            data_per_point['#{0}'.format(i)] = DATA['fa']
+            data_per_point[f'#{i}'] = DATA['fa']
 
             tractogram = Tractogram(DATA['streamlines'],
                                     data_per_point=data_per_point,
@@ -388,7 +382,7 @@ class TestTRK(unittest.TestCase):
             assert_tractogram_equal(new_trk.tractogram, tractogram)
 
         # More than 10 data_per_point should raise an error.
-        data_per_point['#{0}'.format(i+1)] = DATA['fa']
+        data_per_point[f'#{i + 1}'] = DATA['fa']
 
         tractogram = Tractogram(DATA['streamlines'],
                                 data_per_point=data_per_point,
@@ -401,7 +395,7 @@ class TestTRK(unittest.TestCase):
         # TRK supports up to 10 data_per_streamline.
         data_per_streamline = {}
         for i in range(10):
-            data_per_streamline['#{0}'.format(i)] = DATA['mean_torsion']
+            data_per_streamline[f'#{i}'] = DATA['mean_torsion']
 
             tractogram = Tractogram(DATA['streamlines'],
                                     data_per_streamline=data_per_streamline,
@@ -416,7 +410,7 @@ class TestTRK(unittest.TestCase):
             assert_tractogram_equal(new_trk.tractogram, tractogram)
 
         # More than 10 data_per_streamline should raise an error.
-        data_per_streamline['#{0}'.format(i+1)] = DATA['mean_torsion']
+        data_per_streamline[f'#{i + 1}'] = DATA['mean_torsion']
 
         tractogram = Tractogram(DATA['streamlines'],
                                 data_per_streamline=data_per_streamline)
