@@ -6,11 +6,11 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-''' Test Analyze headers
+""" Test Analyze headers
 
 See test_wrapstruct.py for tests of the wrapped structarr-ness of the Analyze
 header
-'''
+"""
 
 import os
 import re
@@ -141,7 +141,8 @@ class TestAnalyzeHeader(_TestLabeledWrapStruct):
             fhdr, message, raiser = self.log_chk(hdr, 30)
 
         assert fhdr['sizeof_hdr'] == self.sizeof_hdr
-        assert message == 'sizeof_hdr should be {0}; set sizeof_hdr to {0}'.format(self.sizeof_hdr)
+        assert (message == f'sizeof_hdr should be {self.sizeof_hdr}; '
+                           f'set sizeof_hdr to {self.sizeof_hdr}')
         pytest.raises(*raiser)
         # RGB datatype does not raise error
         hdr = HC()
@@ -733,9 +734,11 @@ class TestAnalyzeImage(tsi.TestSpatialImage, tsi.MmapImageMixin):
         assert_array_equal(np.asanyarray(img2.dataobj), data)
         # now check read_img_data function - here we do see the changed
         # header
-        sc_data = read_img_data(img2)
+        with pytest.deprecated_call(match="from version: 3.2"):
+            sc_data = read_img_data(img2)
         assert sc_data.shape == (3, 2, 2)
-        us_data = read_img_data(img2, prefer='unscaled')
+        with pytest.deprecated_call(match="from version: 3.2"):
+            us_data = read_img_data(img2, prefer='unscaled')
         assert us_data.shape == (3, 2, 2)
 
     def test_affine_44(self):
