@@ -12,7 +12,7 @@ from ..testing import suppress_warnings
 
 from numpy.testing import (assert_array_almost_equal, assert_array_equal)
 
-from nose.tools import (assert_true, assert_false, assert_equal, assert_raises)
+import pytest
 
 
 def test_shared_range():
@@ -35,7 +35,7 @@ def test_shared_range():
                 # not have an exact representation.
                 fimax = int_to_float(imax, ft)
                 if np.isfinite(fimax):
-                    assert_true(int(fimax) != imax)
+                    assert int(fimax) != imax
                 # Therefore the imax, cast back to float, and to integer, will
                 # overflow. If it overflows to the imax, we need to allow for
                 # that possibility in the testing of our overflowed values
@@ -43,13 +43,11 @@ def test_shared_range():
                 if imax_roundtrip == imax:
                     thresh_overflow = True
             if thresh_overflow:
-                assert_true(np.all(
-                    (bit_bigger == casted_mx) |
-                    (bit_bigger == imax)))
+                assert np.all((bit_bigger == casted_mx) | (bit_bigger == imax))
             else:
-                assert_true(np.all((bit_bigger <= casted_mx)))
+                assert np.all((bit_bigger <= casted_mx))
             if it in np.sctypes['uint']:
-                assert_equal(mn, 0)
+                assert mn == 0
                 continue
             # And something larger for the minimum
             with suppress_warnings():  # overflow
@@ -63,7 +61,7 @@ def test_shared_range():
                 # not have an exact representation.
                 fimin = int_to_float(imin, ft)
                 if np.isfinite(fimin):
-                    assert_true(int(fimin) != imin)
+                    assert int(fimin) != imin
                 # Therefore the imin, cast back to float, and to integer, will
                 # overflow. If it overflows to the imin, we need to allow for
                 # that possibility in the testing of our overflowed values
@@ -71,11 +69,9 @@ def test_shared_range():
                 if imin_roundtrip == imin:
                     thresh_overflow = True
             if thresh_overflow:
-                assert_true(np.all(
-                    (bit_smaller == casted_mn) |
-                    (bit_smaller == imin)))
+                assert np.all((bit_smaller == casted_mn) | (bit_smaller == imin))
             else:
-                assert_true(np.all((bit_smaller >= casted_mn)))
+                assert np.all((bit_smaller >= casted_mn))
 
 
 def test_shared_range_inputs():
@@ -114,7 +110,8 @@ def test_casting():
                 im_exp[1] = ii.max
             assert_array_equal(iarr, im_exp)
             # NaNs, with nan2zero False, gives error
-            assert_raises(CastingError, float_to_int, farr, it, False)
+            with pytest.raises(CastingError):
+                float_to_int(farr, it, False)
             # We can pass through NaNs if we really want
             exp_arr[arr.index(np.nan)] = ft(np.nan).astype(it)
             with np.errstate(invalid='ignore'):
@@ -130,7 +127,8 @@ def test_casting():
     with np.errstate(invalid='ignore'):
         assert_array_equal(float_to_int(np.nan, np.int16), [0])
     # Test nans give error if not nan2zero
-    assert_raises(CastingError, float_to_int, np.nan, np.int16, False)
+    with pytest.raises(CastingError):
+        float_to_int(np.nan, np.int16, False)
 
 
 def test_int_abs():
@@ -139,25 +137,25 @@ def test_int_abs():
         in_arr = np.array([info.min, info.max], dtype=itype)
         idtype = np.dtype(itype)
         udtype = np.dtype(idtype.str.replace('i', 'u'))
-        assert_equal(udtype.kind, 'u')
-        assert_equal(idtype.itemsize, udtype.itemsize)
+        assert udtype.kind == 'u'
+        assert idtype.itemsize == udtype.itemsize
         mn, mx = in_arr
         e_mn = as_int(mx) + 1  # as_int needed for numpy 1.4.1 casting
-        assert_equal(int_abs(mx), mx)
-        assert_equal(int_abs(mn), e_mn)
+        assert int_abs(mx) == mx
+        assert int_abs(mn) == e_mn
         assert_array_equal(int_abs(in_arr), [e_mn, mx])
 
 
 def test_floor_log2():
-    assert_equal(floor_log2(2**9 + 1), 9)
-    assert_equal(floor_log2(-2**9 + 1), 8)
-    assert_equal(floor_log2(2), 1)
-    assert_equal(floor_log2(1), 0)
-    assert_equal(floor_log2(0.5), -1)
-    assert_equal(floor_log2(0.75), -1)
-    assert_equal(floor_log2(0.25), -2)
-    assert_equal(floor_log2(0.24), -3)
-    assert_equal(floor_log2(0), None)
+    assert floor_log2(2**9 + 1) == 9
+    assert floor_log2(-2**9 + 1) == 8
+    assert floor_log2(2) == 1
+    assert floor_log2(1) == 0
+    assert floor_log2(0.5) == -1
+    assert floor_log2(0.75) == -1
+    assert floor_log2(0.25) == -2
+    assert floor_log2(0.24) == -3
+    assert floor_log2(0) is None
 
 
 def test_able_int_type():
@@ -176,7 +174,7 @@ def test_able_int_type():
             ([-1, 2**64 - 1], None),
             ([0, 2**64 - 1], np.uint64),
             ([0, 2**64], None)):
-        assert_equal(able_int_type(vals), exp_out)
+        assert able_int_type(vals) == exp_out
 
 
 def test_able_casting():
@@ -193,11 +191,11 @@ def test_able_casting():
             ApBt = (A + B).dtype.type
             able_type = able_int_type([in_mn, in_mx, out_mn, out_mx])
             if able_type is None:
-                assert_equal(ApBt, np.float64)
+                assert ApBt == np.float64
                 continue
             # Use str for comparison to avoid int32/64 vs intp comparison
             # failures
-            assert_equal(np.dtype(ApBt).str, np.dtype(able_type).str)
+            assert np.dtype(ApBt).str == np.dtype(able_type).str
 
 
 def test_best_float():
@@ -212,51 +210,51 @@ def test_best_float():
     best = best_float()
     end_of_ints = np.float64(2**53)
     # float64 has continuous integers up to 2**53
-    assert_equal(end_of_ints, end_of_ints + 1)
+    assert end_of_ints == end_of_ints + 1
     # longdouble may have more, but not on 32 bit windows, at least
     end_of_ints = np.longdouble(2**53)
     if (end_of_ints == (end_of_ints + 1) or  # off continuous integers
             machine() == 'sparc64' or  # crippling slow longdouble on sparc
             longdouble_precision_improved()):  # Windows precisions can change
-        assert_equal(best, np.float64)
+        assert best == np.float64
     else:
-        assert_equal(best, np.longdouble)
+        assert best == np.longdouble
 
 
 def test_longdouble_precision_improved():
     # Just check that this can only be True on windows, msvc
     from numpy.distutils.ccompiler import get_default_compiler
     if not (os.name == 'nt' and get_default_compiler() == 'msvc'):
-        assert_false(longdouble_precision_improved())
+        assert not longdouble_precision_improved()
 
 
 def test_ulp():
-    assert_equal(ulp(), np.finfo(np.float64).eps)
-    assert_equal(ulp(1.0), np.finfo(np.float64).eps)
-    assert_equal(ulp(np.float32(1.0)), np.finfo(np.float32).eps)
-    assert_equal(ulp(np.float32(1.999)), np.finfo(np.float32).eps)
+    assert ulp() == np.finfo(np.float64).eps
+    assert ulp(1.0) == np.finfo(np.float64).eps
+    assert ulp(np.float32(1.0)) == np.finfo(np.float32).eps
+    assert ulp(np.float32(1.999)) == np.finfo(np.float32).eps
     # Integers always return 1
-    assert_equal(ulp(1), 1)
-    assert_equal(ulp(2**63 - 1), 1)
+    assert ulp(1) == 1
+    assert ulp(2**63 - 1) == 1
     # negative / positive same
-    assert_equal(ulp(-1), 1)
-    assert_equal(ulp(7.999), ulp(4.0))
-    assert_equal(ulp(-7.999), ulp(4.0))
-    assert_equal(ulp(np.float64(2**54 - 2)), 2)
-    assert_equal(ulp(np.float64(2**54)), 4)
-    assert_equal(ulp(np.float64(2**54)), 4)
+    assert ulp(-1) == 1
+    assert ulp(7.999) == ulp(4.0)
+    assert ulp(-7.999) == ulp(4.0)
+    assert ulp(np.float64(2**54 - 2)) == 2
+    assert ulp(np.float64(2**54)) == 4
+    assert ulp(np.float64(2**54)) == 4
     # Infs, NaNs return nan
-    assert_true(np.isnan(ulp(np.inf)))
-    assert_true(np.isnan(ulp(-np.inf)))
-    assert_true(np.isnan(ulp(np.nan)))
+    assert np.isnan(ulp(np.inf))
+    assert np.isnan(ulp(-np.inf))
+    assert np.isnan(ulp(np.nan))
     # 0 gives subnormal smallest
     subn64 = np.float64(2**(-1022 - 52))
     subn32 = np.float32(2**(-126 - 23))
-    assert_equal(ulp(0.0), subn64)
-    assert_equal(ulp(np.float64(0)), subn64)
-    assert_equal(ulp(np.float32(0)), subn32)
+    assert ulp(0.0) == subn64
+    assert ulp(np.float64(0)) == subn64
+    assert ulp(np.float32(0)) == subn32
     # as do multiples of subnormal smallest
-    assert_equal(ulp(subn64 * np.float64(2**52)), subn64)
-    assert_equal(ulp(subn64 * np.float64(2**53)), subn64 * 2)
-    assert_equal(ulp(subn32 * np.float32(2**23)), subn32)
-    assert_equal(ulp(subn32 * np.float32(2**24)), subn32 * 2)
+    assert ulp(subn64 * np.float64(2**52)) == subn64
+    assert ulp(subn64 * np.float64(2**53)) == subn64 * 2
+    assert ulp(subn32 * np.float32(2**23)) == subn32
+    assert ulp(subn32 * np.float32(2**24)) == subn32 * 2
