@@ -8,32 +8,24 @@ from os.path import join as pjoin, abspath
 
 from .. import environment as nibe
 
-from numpy.testing import (assert_array_almost_equal,
-                           assert_array_equal)
+import pytest
 
-from nose.tools import assert_equal
-
-from nose import with_setup
-
-GIVEN_ENV = {}
 DATA_KEY = 'NIPY_DATA_PATH'
 USER_KEY = 'NIPY_USER_DIR'
 
 
-def setup_environment():
+@pytest.fixture
+def with_environment(request):
     """Setup test environment for some functions that are tested
     in this module. In particular this functions stores attributes
     and other things that we need to stub in some test functions.
     This needs to be done on a function level and not module level because
     each testfunction needs a pristine environment.
     """
-    global GIVEN_ENV
+    GIVEN_ENV = {}
     GIVEN_ENV['env'] = env.copy()
-
-
-def teardown_environment():
-    """Restore things that were remembered by the setup_environment function
-    """
+    yield
+    """Restore things that were remembered by the setup_environment function """
     orig_env = GIVEN_ENV['env']
     # Pull keys out into list to avoid altering dictionary during iteration,
     # causing python 3 error
@@ -43,17 +35,12 @@ def teardown_environment():
     env.update(orig_env)
 
 
-# decorator to use setup, teardown environment
-with_environment = with_setup(setup_environment, teardown_environment)
-
-
 def test_nipy_home():
     # Test logic for nipy home directory
-    assert_equal(nibe.get_home_dir(), os.path.expanduser('~'))
+    assert nibe.get_home_dir() == os.path.expanduser('~')
 
 
-@with_environment
-def test_user_dir():
+def test_user_dir(with_environment):
     if USER_KEY in env:
         del env[USER_KEY]
     home_dir = nibe.get_home_dir()
@@ -61,16 +48,16 @@ def test_user_dir():
         exp = pjoin(home_dir, '.nipy')
     else:
         exp = pjoin(home_dir, '_nipy')
-    assert_equal(exp, nibe.get_nipy_user_dir())
+    assert exp == nibe.get_nipy_user_dir()
     env[USER_KEY] = '/a/path'
-    assert_equal(abspath('/a/path'), nibe.get_nipy_user_dir())
+    assert abspath('/a/path') == nibe.get_nipy_user_dir()
 
 
 def test_sys_dir():
     sys_dir = nibe.get_nipy_system_dir()
     if os.name == 'nt':
-        assert_equal(sys_dir, r'C:\etc\nipy')
+        assert sys_dir == r'C:\etc\nipy'
     elif os.name == 'posix':
-        assert_equal(sys_dir, r'/etc/nipy')
+        assert sys_dir == r'/etc/nipy'
     else:
-        assert_equal(sys_dir, None)
+        assert sys_dir is None
