@@ -8,10 +8,6 @@
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """ Tests for imageglobals module
 """
-
-from nose.tools import (assert_true, assert_false, assert_raises,
-                        assert_equal, assert_not_equal)
-
 from .. import imageglobals as igs
 
 
@@ -19,5 +15,5 @@ def test_errorlevel():
     orig_level = igs.error_level
     for level in (10, 20, 30):
         with igs.ErrorLevel(level):
-            assert_equal(igs.error_level, level)
-        assert_equal(igs.error_level, orig_level)
+            assert igs.error_level == level
+        assert igs.error_level == orig_level
