@@ -6,7 +6,7 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-''' Tests for nifti2 reading package '''
+""" Tests for nifti2 reading package """
 import os
 
 import numpy as np
