@@ -47,5 +47,5 @@ class TripWire(object):
         self._msg = msg
 
     def __getattr__(self, attr_name):
-        ''' Raise informative error accessing attributes '''
+        """ Raise informative error accessing attributes """
         raise TripWireError(self._msg)
